@@ -5,7 +5,7 @@
 distname = 'cubicweb-saem-ref'
 modname = 'cubicweb_saem_ref'
 
-numversion = (0, 21, 1)
+numversion = (0, 25, 5)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -16,20 +16,20 @@ web = 'http://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {
     'cubicweb[pyramid]': '>= 3.26.1',
-    'cubicweb-squareui': None,
-    'cubicweb-eac': '>= 0.7.0, < 0.8.0',
-    'cubicweb-seda': '>= 0.14.0, < 0.15.0',
+    'cubicweb-squareui': '>= 1.1.2',
+    'cubicweb-eac': '>= 0.8.4, < 0.9.0',
+    'cubicweb-seda': '>= 0.17.2, < 0.18.0',
     'cubicweb-compound': '>= 0.7.0, < 0.8.0',
     'cubicweb-prov': '>= 0.4.0, < 0.5.0',
-    'cubicweb-oaipmh': '>= 0.5.0, < 0.6.0',
-    'cubicweb-relationwidget': '>= 0.4.0, < 0.5.0',
-    'cubicweb-skos': '>= 1.5.0',
-    'cubicweb-vtimeline': None,
+    'cubicweb-oaipmh': '>= 0.6.0, < 0.7.0',
+    'cubicweb-relationwidget': '>= 0.5.1, < 0.6.0',
+    'cubicweb-skos': '>= 1.6.0',
+    'cubicweb-vtimeline': '>= 0.6.0',
     'cubicweb-signedrequest': None,
     'isodate': None,
     'python-dateutil': None,
     'pytz': None,
-    'psycopg2': None,
+    'psycopg2': '< 2.8',
     'rdflib': '>= 4.1',
 }
 __recommends__ = {}
@@ -37,6 +37,6 @@ __recommends__ = {}
 classifiers = [
     'Environment :: Web Environment',
     'Framework :: CubicWeb',
-    'Programming Language :: Python',
+    'Programming Language :: Python :: 3',
     'Programming Language :: JavaScript',
 ]
