@@ -19,8 +19,8 @@ from logilab.common.decorators import monkeypatch
 
 from cubicweb.predicates import is_instance, is_in_state
 
-from cubes.oaipmh import MetadataFormat
-from cubes.oaipmh.entities import OAISetSpec
+from cubicweb_oaipmh import MetadataFormat
+from cubicweb_oaipmh.entities import OAISetSpec
 from cubicweb_seda.entities import SEDAArchiveTransferIClonableAdapter
 from cubicweb_seda.entities.custom import (
     SEDAArchiveTransfer,
