@@ -15,8 +15,6 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-saem-ref views for import/export of AuthorityRecord from/to EAC"""
 
-from six import text_type
-
 from cubicweb import tags
 from cubicweb.predicates import specified_etype_implements
 from cubicweb.web import formfields as ff
@@ -30,7 +28,7 @@ from .. import user_has_naa, user_has_authority
 def naa_form_vocabulary(form, field):
     """Field vocabulary function returning the list of available authorities"""
     rset = form._cw.execute('Any XN, X ORDERBY XN WHERE X is ArkNameAssigningAuthority, X who XN')
-    return [(name, text_type(eid)) for name, eid in rset]
+    return [(name, str(eid)) for name, eid in rset]
 
 
 class EACImportForm(eac.EACImportForm):
