@@ -36,8 +36,8 @@ affk.set_field_kwargs('ArkNameAssigningAuthority', 'who', widget=fw.TextInput({'
 
 
 class ManagementAddEntityComponent(AddEntityComponent):
-    __select__ = (component.CtxComponent.__select__ & has_permission('add') &
-                  is_instance('Organization', 'ArkNameAssigningAuthority'))
+    __select__ = (component.CtxComponent.__select__ & has_permission('add')
+                  & is_instance('Organization', 'ArkNameAssigningAuthority'))
 
 
 class ARKNamingAutorithyAction(actions.ManagersAction):
