@@ -17,9 +17,7 @@
 
 import datetime
 
-from six import text_type
-
-import mock
+from unittest import mock
 
 from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
@@ -85,7 +83,7 @@ class RDFExportTC(testutils.XmlTestMixin, CubicWebTC):
         ], triples)
 
     def uri(self, s):
-        return text_type(self.reg.normalize_uri(s))
+        return self.reg.normalize_uri(s)
 
     def test_organization_unit(self):
         with self.admin_access.client_cnx() as cnx:
