@@ -27,7 +27,7 @@ from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.pyramid.test import PyramidCWTest
 
-from cubes.oaipmh.views import OAIError, OAIRequest
+from cubicweb_oaipmh.views import OAIError, OAIRequest
 
 from cubicweb_saem_ref import permanent_url
 
@@ -68,15 +68,15 @@ class OAIComponentTC(CubicWebTC, OAITestMixin):
         with self.admin_access.repo_cnx() as cnx:
             oai = self.oai_component(cnx)
             setspecs = oai.__setspecs__
-            self.assertCountEqual(setspecs.keys(),
+            self.assertCountEqual(list(setspecs.keys()),
                                   ['agent', 'organizationunit', 'organization',
                                    'authorityrecord',
                                    'conceptscheme', 'profile', 'concept'])
-            self.assertCountEqual(setspecs['organizationunit'].keys(), ['role'])
-            self.assertCountEqual(setspecs['profile'].keys(),
+            self.assertCountEqual(list(setspecs['organizationunit'].keys()), ['role'])
+            self.assertCountEqual(list(setspecs['profile'].keys()),
                                   ['transferring_agent'])
-            self.assertEqual(setspecs['conceptscheme'].keys(), [])
-            self.assertEqual(setspecs['authorityrecord'].keys(), ['used_by'])
+            self.assertEqual(list(setspecs['conceptscheme'].keys()), [])
+            self.assertEqual(list(setspecs['authorityrecord'].keys()), ['used_by'])
 
     def test_setspecs(self):
         with self.admin_access.repo_cnx() as cnx:
@@ -224,7 +224,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
 
     def test_noverb(self):
         with self.admin_access.web_request() as req:
-            result = self.oai_request(req)
+            result = self.oai_request(req).decode('utf-8')
         self.assertIn('<request>https://localhost:80/oai</request>',
                       result)
         self.assertIn('<error code="badVerb">no verb specified</error',
@@ -232,7 +232,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
 
     def test_badverb(self):
         with self.admin_access.web_request() as req:
-            result = self.oai_request(req, verb='coucou')
+            result = self.oai_request(req, verb='coucou').decode('utf-8')
         self.assertIn('<request>https://localhost:80/oai</request>',
                       result)
         self.assertIn('<error code="badVerb">illegal verb "coucou"</error>',
@@ -243,7 +243,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
     def test_listsets(self):
         pscheme, dscheme = self._setup_schemes()
         with self.admin_access.web_request() as req:
-            result = self.oai_request(req, verb='ListSets')
+            result = self.oai_request(req, verb='ListSets').decode('utf-8')
         self.assertIn('<request verb="ListSets">https://localhost:80/oai</request>',
                       result)
         for spec in ('agent', 'organizationunit', 'conceptscheme', 'profile',
@@ -272,26 +272,26 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='ListIdentifiers',
                                       set='organizationunit',
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(bobby), result)
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(alice), result)
             result = self.oai_request(req, verb='ListIdentifiers',
                                       set='organizationunit:role:producer',
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(alice),
                           result)
             self.assertNotIn('<identifier>ark:/{0}</identifier>'.format(bobby),
                              result)
             result = self.oai_request(req, verb='ListIdentifiers',
                                       set='organizationunit:role:producer',
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(alice), result)
             self.assertNotIn('<identifier>ark:/{0}</identifier>'.format(bobby), result)
             result = self.oai_request(req, verb='ListIdentifiers',
                                       set='conceptscheme',
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             result = self.oai_request(req, verb='ListIdentifiers',
-                                      set='profile', metadataPrefix='seda02xsd')
+                                      set='profile', metadataPrefix='seda02xsd').decode('utf-8')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(profile.ark), result)
 
     def test_listidentifiers_deleted(self):
@@ -310,9 +310,10 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
             result = self.oai_request(req, verb='ListIdentifiers',
                                       set='organizationunit',
                                       metadataPrefix='rdf')
+            xml = result.decode('utf-8')
             self.assertIn(
-                '<identifier>ark:/{0}</identifier>'.format(bobby.ark), result)
-            self.assertIn('<header status="deleted">', result)
+                '<identifier>ark:/{0}</identifier>'.format(bobby.ark), xml)
+            self.assertIn('<header status="deleted">', xml)
             root = etree.fromstring(result)
             ns = root.nsmap[None]
             # only one <header status="..."> element
@@ -326,14 +327,14 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         alice, bobby = self._setup_organization_units()
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='ListRecords', set='organizationunit',
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             self.assertIn(
                 '<rdf:Description rdf:about="{0}">'.format(bobby.url), result)
             self.assertIn(
                 '<rdf:Description rdf:about="{0}">'.format(alice.url), result)
             result = self.oai_request(
                 req, verb='ListRecords', set='organizationunit:role:producer',
-                metadataPrefix='rdf')
+                metadataPrefix='rdf').decode('utf-8')
             self.assertIn(
                 '<rdf:Description rdf:about="{0}">'.format(alice.url), result)
             self.assertNotIn(bobby.url, result)
@@ -343,7 +344,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         self._setup_profile()
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='ListRecords', set='profile',
-                                      metadataPrefix='seda02xsd')
+                                      metadataPrefix='seda02xsd').decode('utf-8')
         # Just ensure a SEDA profile (xsd) is present in response.
         self.assertIn('<metadata><xsd:schema', result)
         self.assertIn('fr:gouv:ae:archive:draft:standard_echange_v0.2', result)
@@ -365,13 +366,13 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
             result = self.oai_request(
                 req, verb='ListIdentifiers',
                 set='profile:transferring_agent:' + transferring_agent_ark,
-                metadataPrefix='seda02xsd')
+                metadataPrefix='seda02xsd').decode('utf-8')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(profile2.ark), result)
             self.assertNotIn(profile.ark, result)
         # Check that without a setspec, we get all profiles.
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='ListIdentifiers',
-                                      set='profile', metadataPrefix='seda02xsd')
+                                      set='profile', metadataPrefix='seda02xsd').decode('utf-8')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(profile.ark), result)
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(profile2.ark), result)
 
@@ -382,14 +383,14 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
             with self.subTest(md_prefix='seda02xsd'):
                 result = self.oai_request(req, verb='GetRecord',
                                           identifier='ark:/' + profile.ark,
-                                          metadataPrefix='seda02xsd')
+                                          metadataPrefix='seda02xsd').decode('utf-8')
                 self.assertIn('<metadata><xsd:schema', result)
                 self.assertIn('http://www.w3.org/2001/XMLSchema', result)
             for md_prefix in ['seda02rng', 'seda1rng', 'seda2rng']:
                 with self.subTest(md_prefix=md_prefix):
                     result = self.oai_request(req, verb='GetRecord',
                                               identifier='ark:/' + profile.ark,
-                                              metadataPrefix=md_prefix)
+                                              metadataPrefix=md_prefix).decode('utf-8')
                     self.assertIn('<metadata><rng:grammar', result)
                     self.assertIn('http://www.w3.org/2001/XMLSchema', result)
 
@@ -403,7 +404,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='GetRecord',
                                       identifier='ark:/' + ark,
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             self.assertIn('name>toto</', result)
             self.assertIn('<rdf:type rdf:resource="http://xmlns.com/foaf/0.1/Person"/>',
                           result)
@@ -417,7 +418,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='GetRecord',
                                       identifier='ark:/' + ark,
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             self.assertIn('title>Default authority</', result)
             self.assertIn('<rdf:type rdf:resource="http://www.w3.org/ns/org#Organization"/>',
                           result)
@@ -432,7 +433,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='GetRecord',
                                       identifier='ark:/' + ark,
-                                      metadataPrefix='rdf')
+                                      metadataPrefix='rdf').decode('utf-8')
             self.assertIn('title>toto</', result)
             self.assertIn('<rdf:type rdf:resource="http://www.w3.org/ns/org#OrganizationUnit"/>',
                           result)
@@ -448,7 +449,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='GetRecord',
                                       identifier='ark:/' + arecord_ark,
-                                      metadataPrefix='eac')
+                                      metadataPrefix='eac').decode('utf-8')
             self.assertIn('<metadata><eac-cpf', result)
             self.assertIn('urn:isbn:1-931666-33-4', result)
 
@@ -472,7 +473,7 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
             result = self.oai_request(
                 req, verb='ListIdentifiers',
                 set='authorityrecord:used_by:{}'.format(ou_ark),
-                metadataPrefix='eac')
+                metadataPrefix='eac').decode('utf-8')
             self.assertIn('<identifier>ark:/' + ark, result)
 
 
