@@ -16,8 +16,6 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-saem-ref test for pyramid views."""
 
-import lxml.etree
-
 from cubicweb.devtools import PostgresApptestConfiguration
 from cubicweb.pyramid.test import PyramidCWTest
 
@@ -69,12 +67,10 @@ class EACWSTC(PyramidCWTest):
                                headers={'Accept': 'application/json'},
                                status=400)
 
-        expected_details = "Start tag expected, '<' not found, line 1, column 1"
-        if lxml.etree.LXML_VERSION[:2] >= (3, 7):
-            expected_details += " (line 1)"
-        self.assertEqual(res.json,
-                         {'error': u'Invalid XML file',
-                          'details': expected_details})
+        resp_data = res.json
+        details = resp_data.pop('details')
+        self.assertIn("Start tag expected, '<' not found, line 1, column 1", details)
+        self.assertEqual(resp_data, {'error': u'Invalid XML file'})
 
         res = self.webapp.post('/authorityrecord',
                                params='<xml xmlns="bla"/>',
