@@ -132,6 +132,17 @@ class NonManagerUserTC(CubicWebTC):
                               label_of=type_concept)
             cnx.commit()
 
+    def test_deprecated_vocabulary_can_be_deleted(self):
+        with self.admin_access.cnx() as cnx:
+            scheme = testutils.setup_scheme(cnx, u'my scheme', u'lab1', u'lab2')
+            cnx.commit()
+            scheme.cw_adapt_to('IWorkflowable').fire_transition('publish')
+            cnx.commit()
+            with self.assertUnauthorized(cnx):
+                scheme.cw_delete()
+            scheme.cw_adapt_to('IWorkflowable').fire_transition('deprecate')
+            scheme.cw_delete()
+
     def test_create_update_agent_in_own_organization(self):
         with self.admin_access.cnx() as cnx:
             other_authority = testutils.authority_with_naa(cnx, name=u'other authority')
@@ -167,7 +178,7 @@ class NonManagerUserTC(CubicWebTC):
         with self.admin_access.cnx() as cnx:
             other_authority = testutils.authority_with_naa(cnx, name=u'other authority')
             other_unit = testutils.organization_unit(
-                cnx, u'arch', archival_roles=[u'archival'], authority=other_authority)
+                cnx, u'arch', archival_roles=[u'deposit'], authority=other_authority)
             profile = testutils.setup_profile(cnx)
             scheme = testutils.scheme_for_type(cnx, u'seda_keyword_type_to', None)
             cnx.commit()
@@ -462,6 +473,13 @@ class ManagerUserTC(CubicWebTC):
                 scheme.cw_delete()
             with self.assertUnauthorized(cnx):
                 new_concept.cw_delete()
+            # deprecated, deletion (and update) is allowed.
+            scheme.cw_adapt_to('IWorkflowable').fire_transition('deprecate')
+            cnx.commit()
+            new_concept.cw_delete()
+            cnx.commit()
+            scheme.cw_delete()
+            cnx.commit()
 
 
 if __name__ == '__main__':
