@@ -16,16 +16,12 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-saem-ref test for views."""
 
+import io
 import json
 import os
 from datetime import date
 from tempfile import NamedTemporaryFile
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
-from six import text_type
+import unittest
 
 from yams.schema import role_name
 
@@ -112,8 +108,8 @@ class FuncViewsTC(CubicWebTC):
         with self.admin_access.web_request() as req:
             req._ = lambda x: x + u' \xe9'
             output = self.view(regid, req=req, template=None)
-            self.assertIn('be in an organization', output)
-            self.assertIn('to access this functionnality', output)
+            self.assertIn(b'be in an organization', output)
+            self.assertIn(b'to access this functionnality', output)
         with self.admin_access.web_request() as req:
             req._ = lambda x: x + u' \xe9'
             authority = req.cnx.create_entity('Organization', name=u'dummy',
@@ -121,8 +117,8 @@ class FuncViewsTC(CubicWebTC):
             req.user.cw_set(authority=authority)
             req.cnx.commit()
             output = self.view(regid, req=req, template=None)
-            self.assertIn('have an NAA configured', output)
-            self.assertIn('to access this functionnality', output)
+            self.assertIn(b'have an NAA configured', output)
+            self.assertIn(b'to access this functionnality', output)
 
     def test_eac_import_ok(self):
         regid = 'eac.import'
@@ -132,8 +128,8 @@ class FuncViewsTC(CubicWebTC):
             naa = req.cnx.create_entity('ArkNameAssigningAuthority', who=u'EAC', what=1)
             # simply test the form properly render and is well formed
             self.view(regid, req=req, template=None)
-            fields = {'file': (fname, open(self.datapath('EAC/' + fname))),
-                      'naa': text_type(naa.eid)}
+            fields = {'file': (fname, io.open(self.datapath('EAC/' + fname), 'rb')),
+                      'naa': str(naa.eid)}
             req.form = self.fake_form(regid, fields)
             # now actually test the import
             req.view(regid)
@@ -146,11 +142,12 @@ class FuncViewsTC(CubicWebTC):
         with self.admin_access.client_cnx() as cnx:
             scheme = testutils.setup_scheme(cnx, u'my thesaurus')
             cnx.commit()
-            url = scheme.absolute_url(highlight='toto')
+            url = scheme.absolute_url()
+        html = self.http_publish(url, data={'highlight': 'toto'})[0].decode('utf-8')
         self.assertIn(
             '$(document).ready(function(){$("h1, h2, h3, h4, h5, table tbody td")'
             '.highlight("toto");});}',
-            self.http_publish(url)[0])
+            html)
 
     def test_highlight_on_rql_plain_text_search_same_etype(self):
         with self.admin_access.client_cnx() as cnx:
@@ -159,8 +156,9 @@ class FuncViewsTC(CubicWebTC):
             concept = scheme.reverse_in_scheme[0]
             cnx.commit()
             ark = concept.ark
-        url = 'http://testing.fr/cubicweb/view?rql=toto&__fromsearchbox=1&subvid=tsearch'
-        html = self.http_publish(url)[0]
+        url = 'http://testing.fr/cubicweb/view'
+        data = {'rql': 'toto', '__fromsearchbox': '1', 'subvid': 'tsearch'}
+        html = self.http_publish(url, data=data)[0].decode('utf-8')
         self.assertIn(
             '<a href="http://testing.fr/cubicweb/ark:/{}?highlight=toto" title="">'.format(ark),
             html)
@@ -376,7 +374,7 @@ class ArkViewsTC(CubicWebTC):
             scheme.eid = 'A'
             fields = {role_name('title', 'subject'): u'test',
                       role_name('ark', 'subject'): u'',
-                      role_name('ark_naa', 'subject'): text_type(testutils.naa(req.cnx).eid)}
+                      role_name('ark_naa', 'subject'): str(testutils.naa(req.cnx).eid)}
             req.form = self.fake_form('edition', entity_field_dicts=[(scheme, fields)])
             path = self.expect_redirect_handle_request(req)[0]
             self._check_entity_from_path(req, path, 'ConceptScheme',
@@ -417,7 +415,7 @@ class AssignArkWebServiceTC(CubicWebTC):
         with self.new_access('anon').web_request(headers={'Accept': 'application/json'},
                                                  method='POST') as req:
             result = self.app_handle_request(req, 'ark')
-            self.assertEqual(json.loads(result),
+            self.assertEqual(json.loads(result.decode('utf-8')),
                              [{'error': 'This service requires authentication.'}])
 
     def test_authenticated_missing_organization(self):
@@ -425,7 +423,7 @@ class AssignArkWebServiceTC(CubicWebTC):
                 'ark',
                 headers={'Accept': 'application/json'}, method='POST') as req:
             result = self.app_handle_request(req)
-            self.assertEqual(json.loads(result),
+            self.assertEqual(json.loads(result.decode('utf-8')),
                              [{'error': 'Missing required "organization" query parameter.'}])
 
     def test_authenticated_organization_method_not_post(self):
@@ -435,7 +433,7 @@ class AssignArkWebServiceTC(CubicWebTC):
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'}, **params) as req:
             result = self.app_handle_request(req, 'ark')
-            self.assertEqual(json.loads(result),
+            self.assertEqual(json.loads(result.decode('utf-8')),
                              [{'error': 'This service is only accessible using POST.'}])
 
     def test_authenticated_organization_does_not_exist_method_post(self):
@@ -446,7 +444,7 @@ class AssignArkWebServiceTC(CubicWebTC):
                 headers={'Accept': 'application/json'},
                 method='POST', **bad_params) as req:
             result = self.app_handle_request(req, 'ark')
-            self.assertEqual(json.loads(result),
+            self.assertEqual(json.loads(result.decode('utf-8')),
                              [{'error': expected_msg.format(0)}])
         # Specified ark does not match an Organization entity.
         with self.admin_access.cnx() as cnx:
@@ -456,7 +454,7 @@ class AssignArkWebServiceTC(CubicWebTC):
                 headers={'Accept': 'application/json'},
                 method='POST', **bad_params) as req:
             result = self.app_handle_request(req, 'ark')
-            self.assertEqual(json.loads(result),
+            self.assertEqual(json.loads(result.decode('utf-8')),
                              [{'error': expected_msg.format(agent_ark)}])
 
     def test_authenticated_organization_has_no_naa_method_post(self):
@@ -470,7 +468,7 @@ class AssignArkWebServiceTC(CubicWebTC):
                 method='POST', **bad_params) as req:
             result = self.app_handle_request(req, 'ark')
             expected_msg = 'Organization "{0}" cannot assign ARK identifiers.'
-            self.assertEqual(json.loads(result),
+            self.assertEqual(json.loads(result.decode('utf-8')),
                              [{'error': expected_msg.format(org_ark)}])
 
     def test_ok(self):
@@ -479,7 +477,7 @@ class AssignArkWebServiceTC(CubicWebTC):
             cnx.commit()
 
         def check_ark(response_body):
-            json_response = json.loads(result)
+            json_response = json.loads(result.decode('utf-8'))
             self.assertEqual(len(json_response), 1)
             self.assertEqual(list(json_response[0].keys()), ['ark'])
             ark = json_response[0]['ark']
@@ -534,7 +532,7 @@ class ListArchivalUnitsServiceTC(CubicWebTC):
 
         with self.admin_access.web_request(
                 headers={'Accept': 'application/json'}) as req:
-            result = json.loads(self.app_handle_request(req, 'archival-units'))
+            result = json.loads(self.app_handle_request(req, 'archival-units').decode('utf-8'))
             expected = [
                 {
                     'ark': archival_unit.ark,
@@ -583,8 +581,8 @@ class ListArchivalUnitsServiceTC(CubicWebTC):
                     ],
                 },
             ]
-            result[0]['deposit-units'].sort()
-            expected[0]['deposit-units'].sort()
+            result[0]['deposit-units'].sort(key=lambda d: list(d))
+            expected[0]['deposit-units'].sort(key=lambda d: list(d))
             self.assertEqual(result, expected)
 
 
@@ -617,7 +615,7 @@ class TimelineViewsTC(CubicWebTC):
             ar2 = req.entity_from_eid(ar2.eid)
             ar1 = req.entity_from_eid(ar1.eid)
             data = json.loads(ar3.view(
-                'saem.authorityrecord-timeline-json', w=None))
+                'saem.authorityrecord-timeline-json', w=None).decode('utf-8'))
             predecessors = [x for x in data['timeline']['date']
                             if x['tag'] == u'chronological_predecessor']
             self.assertEqual(len(predecessors), 2)
@@ -630,23 +628,28 @@ class BaseViewsTC(CubicWebTC):
     """Test for non-business views."""
     configcls = PostgresApptestConfiguration
 
-    def expected_notfound_html(self, etype, addlink=False):
+    def expected_notfound_html(self, etype, addlink=False, kwargs=None):
         parts = [
             '<div class="searchMessage">No entity of type &quot;{}&quot; yet.'.format(etype)
         ]
         if addlink:
+            path = 'add/' + etype
+            if kwargs:
+                path = '{}?{}'.format(
+                    path, '&'.join(['{}={}'.format(k, v) for k, v in kwargs.items()]))
             parts.append(
-                ' <a href="http://testing.fr/cubicweb/add/{}">Create one?</a>'.format(etype)
+                ' <a href="http://testing.fr/cubicweb/{}">Create one?</a>'.format(path)
             )
         parts.append('</div>')
         return ''.join(parts)
 
     def test_noresult_sedalib(self):
         with self.admin_access.web_request() as req:
-            result = self.app_handle_request(req, path='/sedalib')
-            self.assertIn(self.expected_notfound_html('SEDAArchiveUnit', True), result)
+            result = self.app_handle_request(req, path='/sedalib').decode('utf-8')
+            kwargs = {'unit_type': 'unit_content'}
+            self.assertIn(self.expected_notfound_html('SEDAArchiveUnit', True, kwargs), result)
         with self.new_access('anon').web_request() as req:
-            result = self.app_handle_request(req, path='/sedalib')
+            result = self.app_handle_request(req, path='/sedalib').decode('utf-8')
             self.assertIn(self.expected_notfound_html('SEDAArchiveUnit'), result)
 
     def test_no_notfound_when_no_entity(self):
@@ -655,10 +658,10 @@ class BaseViewsTC(CubicWebTC):
         """
         with self.admin_access.web_request() as req:
             # Request /bookmark, usually there's none on a fresh instance.
-            result = self.app_handle_request(req, path='/bookmark')
+            result = self.app_handle_request(req, path='/bookmark').decode('utf-8')
             self.assertIn(self.expected_notfound_html('Bookmark', True), result)
         with self.new_access('anon').web_request() as req:
-            result = self.app_handle_request(req, path='/bookmark')
+            result = self.app_handle_request(req, path='/bookmark').decode('utf-8')
             self.assertIn(self.expected_notfound_html('Bookmark'), result)
 
     def test_true_404(self):
