@@ -15,6 +15,8 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
+import io
+
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.devtools import PostgresApptestConfiguration
 
@@ -93,7 +95,7 @@ class LCSVImportTC(CubicWebTC):
             scheme = cnx.create_entity('ConceptScheme', ark_naa=testutils.naa(cnx))
             cnx.commit()
             cnx.call_service('lcsv.skos.import', scheme_uri=scheme.cwuri,
-                             stream=open(self.datapath('lcsv_example_shortened.csv')),
+                             stream=io.open(self.datapath('lcsv_example_shortened.csv'), 'rb'),
                              delimiter='\t', encoding='utf-8', language_code='es')
             concept1 = cnx.find(
                 'Concept', definition="Définition de l'organisation politique de l'organisme").one()
